@@ -23,7 +23,18 @@ def load_command(name: str) -> Callable:
     return _load
 
 
-COMMANDS = ["about", "auth", "log", "task list", "task activate", "task sleep", "view"]
+COMMANDS = [
+    "about",
+    "auth",
+    "log",
+    "meeting join",
+    "meeting peek",
+    "tag",
+    "task list",
+    "task activate",
+    "task sleep",
+    "view",
+]
 
 
 class Application(BaseApplication):
