@@ -1,14 +1,16 @@
 import sys
 
-from typing import TYPE_CHECKING, Any
-from typing import List, Dict
+from typing import TYPE_CHECKING
+from typing import Any
+from typing import Dict
+from typing import List
 
 from cleo.commands.command import Command as BaseCommand
 from pendulum.datetime import DateTime
 from wheat.calendar.calendar import Calendar
-from wheat.harvest.projects.task import Task
 from wheat.factory import Factory
 from wheat.harvest.harvest import Harvest
+from wheat.harvest.projects.task import Task
 from wheat.harvest.time_entry import TimeEntry
 
 
@@ -41,7 +43,7 @@ class Command(BaseCommand):
             self._calendar = Factory(self.io).create_google_calendar()
 
         return self._calendar
-   
+
     @property
     def service(self) -> Any:
         if self._service is None:
@@ -74,10 +76,10 @@ class Command(BaseCommand):
 
         for client, hours in clients.items():
             self.line(f"    {client}: {hours} <success>✔️</success>")
-    
+
     def active_tasks(self) -> List[tuple]:
         clients = self.harvest.projects.all()
-        
+
         tasks = []
         for client, projects in clients.items():
             for project in projects:
@@ -99,5 +101,5 @@ class Command(BaseCommand):
         self.line(f"You have {len(tasks)} active <c1>tasks</c1>.")
         self.line(help)
         self.line("")
-        
-        return tasks
\ No newline at end of file
+
+        return tasks
