@@ -1,15 +1,15 @@
-
 from typing import Any
 from typing import Dict
-from typing import List, Tuple
-from wheat.calendar.calendar import Calendar
-from wheat.factory import Factory
+from typing import List
+from typing import Tuple
 
 import pendulum
 
 from cleo.helpers import option
 from pendulum.datetime import DateTime
+from wheat.calendar.calendar import Calendar
 from wheat.console.commands.command import Command
+from wheat.factory import Factory
 from wheat.harvest.projects.project import Project
 from wheat.harvest.time_entry import TimeEntry
 from wheat.utils.time import month_normalizer
@@ -156,16 +156,18 @@ Examples:
             self.line(f"Hours for {date} (enter to skip task, 'n' to exit):")
             for task in tasks:
                 question = self.create_question(f"  {task[3]}:")
-                
+
                 if calendar is not None:
                     if missing_tags > 0:
-                        self.line(f"  (you have <w>{missing_tags}</w> untagged calendar events)")
-                    
+                        self.line(
+                            f"  (you have <w>{missing_tags}</w> untagged calendar events)"
+                        )
+
                     task_hours = hours_per_task[task[3]]
                     if task_hours > 0:
                         cal_text = f"<c3>[calendar: {task_hours}]</c3>"
                         question = self.create_question(f"  {task[3]}{cal_text}:")
-                
+
                 hours = self.ask(question)
 
                 if hours is None:
@@ -224,12 +226,14 @@ Examples:
         self.line(f"You have {len(tasks)} active <c1>tasks</c1>.")
         self.line(help)
         self.line("")
-        
+
         return tasks
 
-    def parse_events(self, calendar: Calendar, day: DateTime, tasks: List[Tuple]) -> Tuple[Dict[str, int], int]:
+    def parse_events(
+        self, calendar: Calendar, day: DateTime, tasks: List[Tuple]
+    ) -> Tuple[Dict[str, int], int]:
         hours_per_task = {task[3]: 0 for task in tasks}
-        
+
         missing_tags = 0
         for ev in calendar.events_between(day.start_of("day"), day.end_of("day")):
             if not ev.tagged:
@@ -242,5 +246,5 @@ Examples:
             for task in tasks:
                 if task[4] == short:
                     hours_per_task[task[3]] += duration
-            
-        return hours_per_task, missing_tags
\ No newline at end of file
+
+        return hours_per_task, missing_tags
