@@ -1,9 +1,9 @@
 from typing import TYPE_CHECKING
 from typing import List
 
-from wheat.harvest.time_entry import TimeEntry
 from httplib2 import Response
-from pendulum import datetime
+from pendulum.datetime import DateTime
+from wheat.harvest.time_entry import TimeEntry
 
 
 if TYPE_CHECKING:
@@ -18,21 +18,35 @@ class Timesheet:
     def api(self) -> "HarvestClient":
         return self._client
 
-    def fmt_date(self, date: datetime) -> str:
+    def fmt_date(self, date: DateTime) -> str:
         return date.format("YYYY-MM-DD")
 
-    def day(self, date: datetime) -> List[TimeEntry]:
+    def day(self, date: DateTime) -> List[TimeEntry]:
         date = self.fmt_date(date)
 
-        return [TimeEntry(entry) for entry in self.api.entries(date)]
+        response = self.api.entries(date).json()
+        return [TimeEntry(entry) for entry in response["time_entries"]]
+
+    def week(self, start: DateTime, end: DateTime) -> List[TimeEntry]:
+        start = self.fmt_date(start)
+        end = self.fmt_date(end)
+
+        response = self.api.entries(start, end).json()
+        return [TimeEntry(entry) for entry in response["time_entries"]]
 
     def set_hours(
-        self, client: int, project: int, task: int, day: int, hours: float
-    ) -> Response:
+        self,
+        client: str,
+        project: int,
+        task: int,
+        day: DateTime,
+        entries: List[TimeEntry],
+        hours: float,
+    ) -> TimeEntry:
         api = self.api
 
         # If theres already an entry on this day, update it.
-        for entry in self.day(day):
+        for entry in entries:
             if entry.check(client, project, task):
                 return api.update_entry(entry.id, hours=hours)
 
